@@ -7,8 +7,6 @@ from pytconf.config import ( # noqa F401
     config_arg_parse_and_launch,
     register_endpoint,
     get_free_args,
-    write_config_file_json_user,
-    write_config_file_json_system,
-    rm_config_file_json_user,
-    rm_config_file_json_system,
+    write_config_file,
+    rm_config_file,
 )
